# Gabriel Python Module

Python module for communicating with a [Gabriel Server](https://github.com/cmusatyalab/gabriel-server-common).

## Installation
Requires Python >= 3.5

Run `pip install gabriel-client`

## Publishing Changes to PyPi

Update the version number in setup.py. Then follow [these instructions](https://packaging.python.org/tutorials/packaging-projects/#generating-distribution-archives).
